function [p_val,params]=cocktail_synthKStest(data,lo_rt,hi_rt,type)
%function [p_val,params]=cocktail_synthKStest(data,lo_rt,hi_rt,type)
% This code generates a KS significance test for the cocktail
% as described in Clauset, 2009 if type==1. If type ~=1,
% it completes a faster 2-step procedure (default). Both are computationally intensive,
% and parallel processing is recommended. One work-around is to compute a standard
% KS test comparing the best fit distribution to ideal PDF, and only use
% the synthetic routine when the p-value of a standard KS test is found
% to be in the neighborhood of .1


if nargin<4, type=0; end % defaults to the 2-step method

%impose desired data censoring
data(data < lo_rt | data > hi_rt | isnan(data))=[];
% fit the full model
[params] =  cocktail_model_estimation(data);

reps=2500; %number of repetitions. For computing p values
% reps should be ~2500.

KSpVals=zeros(reps,1); %Col vector to store D values. 
   
if type==1
       % Clauset et al. 2009 3-step method, likes less than 1% noise
       % Requires about an hour on an 8-core Mac, with parallel support.
        parfor i=1:reps
         %generate random variable based on best fit, store in a vector.
         sdata = cocktail_inv(length(data),params);
         sdata(sdata < lo_rt | sdata > hi_rt | isnan(sdata))=[];
         % D off best fit to simulated data, with new fits 
         [output] =  cocktail_model_estimation(sdata);
         [~,~,D] = kstest(sdata,[sdata,cocktail_cdf(sdata,output)']);
         KSpVals(i,1)=D; %keep track of D for simulated fits.
        end
        
elseif type~=1
        
       parfor i=1:reps
         % 2-step procedure, capatalizes on statstical fluctuations, but
         % more tolerant of noise ~5%. Takes about 20 sec on an 8-core Mac
         % generate random variable based on best fit, store in a vector.
         sdata = cocktail_inv(length(data),params);
         sdata(sdata < lo_rt | sdata > hi_rt | isnan(sdata))=[];
         % D off best fit from original parameters emperical distribution
         [~,~,D] = kstest(sdata,[sdata,cocktail_cdf(sdata,params)']);
         KSpVals(i,1)=D; %keep track of D for simulated fits.
        end
           
end      
         %D for actual fit.
         [~,~,Do] = kstest(data,[data,cocktail_cdf(data,params)']);  
         %Compare observed D to distribution of D based on synth fits.
         p_val=(length(KSpVals(KSpVals>Do))/reps); %get p value
    
   
        
        
